aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/vendor/github.com/google/pprof/internal/plugin
diff options
context:
space:
mode:
Diffstat (limited to 'src/cmd/vendor/github.com/google/pprof/internal/plugin')
-rw-r--r--src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go15
1 files changed, 10 insertions, 5 deletions
diff --git a/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go b/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go
index 0003656026..23338bc040 100644
--- a/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go
+++ b/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go
@@ -41,7 +41,8 @@ type Options struct {
//
// A common use for a custom HTTPServer is to provide custom
// authentication checks.
- HTTPServer func(args *HTTPServerArgs) error
+ HTTPServer func(args *HTTPServerArgs) error
+ HTTPTransport http.RoundTripper
}
// Writer provides a mechanism to write data under a certain name,
@@ -71,12 +72,16 @@ type FlagSet interface {
// single flag
StringList(name string, def string, usage string) *[]*string
// ExtraUsage returns any additional text that should be
// printed after the standard usage message.
// The typical use of ExtraUsage is to show any custom flags
// defined by the specific pprof plugins being used.
ExtraUsage() string
+ // AddExtraUsage appends additional text to the end of the extra usage message.
+ AddExtraUsage(eu string)
+
// Parse initializes the flags with their values for this run
// and returns the non-flag command line arguments.
// If an unknown flag is encountered or there are no arguments,
@@ -71,12 +72,16 @@ type FlagSet interface {
// single flag
StringList(name string, def string, usage string) *[]*string
- // ExtraUsage returns any additional text that should be
- // printed after the standard usage message.
- // The typical use of ExtraUsage is to show any custom flags
- // defined by the specific pprof plugins being used.
+ // ExtraUsage returns any additional text that should be printed after the
+ // standard usage message. The extra usage message returned includes all text
+ // added with AddExtraUsage().
+ // The typical use of ExtraUsage is to show any custom flags defined by the
+ // specific pprof plugins being used.
ExtraUsage() string